pub struct ParameterMetadata {
pub name: String,
pub ty: ParameterType,
pub default: Option<ParameterValue>,
pub required: bool,
}Expand description
A.1: Parameter metadata for primitives, including defaults. Used during expansion to resolve parameters when no binding is provided.
Fields
name: Stringty: ParameterTypedefault: Option<ParameterValue>required: boolTrait Implementations
Sourceimpl Clone for ParameterMetadata
impl Clone for ParameterMetadata
Sourcefn clone(&self) -> ParameterMetadata
fn clone(&self) -> ParameterMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParameterMetadata
impl Debug for ParameterMetadata
Sourceimpl PartialEq for ParameterMetadata
impl PartialEq for ParameterMetadata
Sourcefn eq(&self, other: &ParameterMetadata) -> bool
fn eq(&self, other: &ParameterMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ParameterMetadata