#[non_exhaustive]pub enum ExpandError {
Show 21 variants
InvariantViolation(String),
EmptyCluster,
MissingCluster {
id: String,
version: Version,
},
InvalidVersionSelector {
target_kind: VersionTargetKind,
id: String,
selector: Version,
},
UnsatisfiedVersionConstraint {
target_kind: VersionTargetKind,
id: String,
selector: Version,
available_versions: Vec<Version>,
},
InvalidAvailableVersion {
target_kind: VersionTargetKind,
id: String,
version: Version,
},
DuplicateInputPort {
name: String,
},
DuplicateOutputPort {
name: String,
},
DuplicateParameter {
name: String,
},
ParameterDefaultTypeMismatch {
name: String,
expected: ParameterType,
got: ParameterType,
},
InvalidDeriveKeySlot {
parameter: String,
},
SignatureInferenceFailed(SignatureInferenceError),
DeclaredSignatureInvalid(ClusterValidationError),
MissingRequiredParameter {
cluster_id: String,
parameter: String,
},
ParameterBindingTypeMismatch {
cluster_id: String,
parameter: String,
expected: ParameterType,
got: ParameterType,
},
ExposedParameterNotFound {
cluster_id: String,
parameter: String,
referenced: String,
},
ExposedParameterTypeMismatch {
cluster_id: String,
parameter: String,
expected: ParameterType,
got: ParameterType,
},
UnresolvedExposedBinding {
node_id: String,
parameter: String,
referenced: String,
},
UndeclaredParameter {
node_id: String,
parameter: String,
},
UnmappedBoundaryOutput {
port_name: String,
node_id: String,
},
UnmappedNestedOutput {
cluster_id: String,
port_name: String,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvariantViolation(String)
A kernel expansion invariant was violated.
EmptyCluster
MissingCluster
InvalidVersionSelector
I.6: Node version selector is not valid semver or semver constraint syntax.
UnsatisfiedVersionConstraint
I.6: No available version satisfies the selector.
InvalidAvailableVersion
I.6: Registered available version is not strict semver.
DuplicateInputPort
DuplicateOutputPort
DuplicateParameter
ParameterDefaultTypeMismatch
InvalidDeriveKeySlot
SignatureInferenceFailed(SignatureInferenceError)
DeclaredSignatureInvalid(ClusterValidationError)
MissingRequiredParameter
I.3: Required parameter has no binding and no default
ParameterBindingTypeMismatch
I.4: Literal binding has wrong type
ExposedParameterNotFound
I.5: Exposed binding references nonexistent parent parameter
ExposedParameterTypeMismatch
I.4: Exposed binding has incompatible type with parent parameter
UnresolvedExposedBinding
Exposed binding was not resolved during expansion (no parent provided a value)
UndeclaredParameter
I.7: Binding references a parameter not declared in the target’s manifest
UnmappedBoundaryOutput
D.4: Boundary output references unmapped node_id
UnmappedNestedOutput
D.4: Nested cluster output port references unmapped node